@@ -93,8 +93,7 @@ class ModuleManager:
     def find(self, key: Union[str, int]) -> Optional[Module]:
         if isinstance(key, int):
             region = self._memory.find_region(key)
-            if region is not None and region.info:
-                assert isinstance(region.info, Module)
+            if region is not None and isinstance(region.info, Module):
                 return region.info
             return None
         if isinstance(key, str):
